@@ -7,10 +7,12 @@ import pytest
 
 from virtualenv.config.cli.parser import VirtualEnvOptions
 from virtualenv.config.ini import IniConfig
+from virtualenv.create.via_global_ref.builtin.cpython.common import is_macos_brew
+from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.run import session_via_cli
 
 
-@pytest.fixture()
+@pytest.fixture
 def _empty_conf(tmp_path, monkeypatch):
     conf = tmp_path / "conf.ini"
     monkeypatch.setenv(IniConfig.VIRTUALENV_CONFIG_FILE_ENV_VAR, str(conf))
@@ -74,10 +76,11 @@ def test_extra_search_dir_via_env_var(tmp_path, monkeypatch):
 
 
 @pytest.mark.usefixtures("_empty_conf")
+@pytest.mark.skipif(is_macos_brew(PythonInfo.current_system()), reason="no copy on brew")
 def test_value_alias(monkeypatch, mocker):
-    from virtualenv.config.cli.parser import VirtualEnvConfigParser
+    from virtualenv.config.cli.parser import VirtualEnvConfigParser  # noqa: PLC0415
 
-    prev = VirtualEnvConfigParser._fix_default
+    prev = VirtualEnvConfigParser._fix_default  # noqa: SLF001
 
     def func(self, action):
         if action.dest == "symlinks":
